@@ -54,6 +54,10 @@ class Pose:
         return Pose(Vector3(pose.get('x', 0.0), pose.get('y', 0.0), pose.get('z', 0.0)),
                     Vector3(pose.get('rx', 0.0), pose.get('ry', 0.0), pose.get('rz', 0.0)), name=pose.get('name', ''))
 
+    @staticmethod
+    def from_list(pose: List) -> 'Pose':
+        return Pose(Vector3(pose[0], pose[1], pose[2]), Vector3(pose[3], pose[4], pose[5]))
+
     @staticmethod
     def pose_trans(p1: 'Pose', p2: 'Pose') -> 'Pose':
         # from: https://forum.universal-robots.com/t/pose-trans-and-pose-inv-functions-in-urcap/1257 (scroll a bit down)
